@@ -1,21 +1,18 @@
 # pylint: disable=missing-class-docstring,missing-function-docstring
-import sys
-from os import PathLike
-from typing import Generic, Iterator, OrderedDict, Protocol, Tuple, Type, TypeVar, Union
+from typing import Generic, Iterator, OrderedDict, Protocol, Tuple, Type, TypeVar
 import torch
 from torch import nn
+from lightkit.utils import PathType
 
 C = TypeVar("C", covariant=True)
 M = TypeVar("M", bound="ConfigurableModule")  # type: ignore
 
-if sys.version_info < (3, 9, 0):
-    # PathLike is not generic for Python 3.9
-    PathType = Union[str, PathLike]
-else:
-    PathType = Union[str, PathLike[str]]
 
+class ConfigurableModule(Protocol, Generic[C]):
+    @property
+    def config(self) -> C:
+        ...
 
-class AnyConfigurableModule(Protocol):
     @classmethod
     def load(cls: Type[M], path: PathType) -> M:
         ...
@@ -34,9 +31,3 @@ class AnyConfigurableModule(Protocol):
 
     def load_state_dict(self, state_dict: OrderedDict[str, torch.Tensor]) -> None:
         ...
-
-
-class ConfigurableModule(AnyConfigurableModule, Protocol, Generic[C]):
-    @property
-    def config(self) -> C:
-        ...
